# Load all libraries needed
# Make certain that you have all the following packages installed
library(assertthat)
library(RColorBrewer)
library(grid)
library(gridExtra)
library(lubridate)
library(nlme)
library(plyr)
library(reshape2)
library(robustHD)
library(segmented)
library(stringr)

# Clean up environment
rm(list=ls(all=TRUE))
graphics.off()

# Set the seed of the random number generator (you CAN change this)
set.seed(131161)

# Set the folder where the R scripts reside on your computer (you MUST change this)
setwd("C:/Users/au152367/Documents/PAPERS/2017/BC/re-re-submit/R")

# Load shared functions and settings
source("bc-general.R")
source("settings.R")
source("solar-time.R")

# Create output folder as needed
if (!dir.exists("output")) {
  dir.create("output")
}
if (!dir.exists("output/keys")) {
  dir.create("output/keys")
}

# Generate all outputs needed for statistics, figures and tables
# In R GUI, uncheck 'Buffered output' to follow the progress on screen
run = function(name) {
  print(paste("At", Sys.time(), "running:  ", name, "..."))
  source(name)
  print(paste("At", Sys.time(), "finished: ", name, "..."))
}

run("1-prepare-data-frames.R")
run("2-fit-slr.R")  #Warning: This step takes some hours
run("3-extract-best-slr.R")
run("4-extract-canyons.R")
run("5-merge-canyons.R")
run("6-do-statistics.R")
run("7-summary.R")

# Generate all figures and tables
run("fig-1-hambleton-diagram.R")
run("fig-2-slr-keys.R")
run("fig-2-slr-examples.R")
run("fig-3-slr-overview.R")
run("fig-4-extracted-segments.R")
run("fig-5-scatter-plots.R")
run("fig-6-density-plots.R")
run("table1-2.R")
