#
# Functions
#

prev_exists = function(hive, date) {
  y = subset(WD_canyons, Hive==hive & Date==date-1)
  nrow(y)==1
}

next_exists = function(hive, date) {
  y = subset(WD_canyons, Hive==hive & Date==date+1)
  nrow(y)==1
}

#
# Main
#

load("output/WD.Rdata")
load("output/canyons.Rdata")

# Extend canyons with WD data 
WD_canyons = join(canyons[, c("Hive", "Date", "CanyonDepth", 
"CanyonHour", "CanyonHourBegin", "CanyonHourEnd",
"CanyonSlope", "CanyonSlopeUp",
"NightFrom", "NightTo", "NightSlope", 
"Category", "NumSegments", "CanyonR2")], WD, type="left")

# For every hive x date instance with no previous or following hive x date instance,
# set WeightGainPrev or WeightGain, respectively, to NA
WD_canyons = ddply(WD_canyons, .(Hive,Date), mutate, 
  WeightGainPrevExists = prev_exists(Hive, Date),
  WeightGainExists = next_exists(Hive, Date)
)

WD_canyons$WeightGainPrev[!WD_canyons$WeightGainPrevExists] = NA
WD_canyons$WeightGain[!WD_canyons$WeightGainExists] = NA

# Remove the two columns after use
ix_col = which("WeightGainPrevExists"==colnames(WD_canyons) | "WeightGainExists"==colnames(WD_canyons))
WD_canyons = WD_canyons[,-ix_col]

save(WD_canyons, file="output/WD_canyons.Rdata")
