#
# Functions
#

which.median = function(v) {
  n = length(v)
  med = if (n%%2 == 1) median(v) else median(v[1:(n-1)])
  which(v==med)  
}

extract_median_fit = function(M) {
  ix = which.median(M$CanyonR2)
  m = M[ix,]
  data.frame(
    Hive = m$Hive,
    Date = m$Date,
    R2 = m$CanyonR2,
    N = nrow(M),
    R2min = min(M$CanyonR2),
    R2max = max(M$CanyonR2)
  )
}

create_title = function(model) { 
  hive = as.character(model$Hive)
  hive = gsub("^H", "#", hive)
  hive = gsub("^hive", "#", hive)
  m = subset(WD_canyons, Hive==model$Hive & Date==model$Date)
  paste0(model$Date, " ", hive) #, " (r2=", round(m$CanyonR2,2), ")")
}

plot_segment_model = function(segment_model) {
  if (is.null(segment_model)) return(NULL)
  hive = segment_model$Hive
  date = segment_model$Date
  model = segment_model$Model.BestModel
  if (is.null(model)) return(NULL)
  line_segments = extract_segments(model)$LinePlot
  M = subset_hive_date(W, hive, date)
  sun = sunshine(M)
  
  ggplot(M, aes(x=Hour, y=Weight)) + 
    geom_rect(aes(xmin=sun[1], xmax=sun[2], ymin=-Inf, ymax=Inf), fill="grey80", colour=NA) +
    theme(
      panel.background = element_rect(fill = "grey70"),
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      axis.title = element_blank(),
      plot.title = element_text(size=10)
    ) +
    guides(colour=FALSE) +
    geom_line(aes(X, Y, colour=Line), data=line_segments, size=2) +
    geom_line()+
    # geom_point() +
    scale_x_continuous(breaks=4*(0:6), limits=c(0,24)) +
    labs(title=create_title(segment_model))       
}

#
# Main
#

load("output/W.Rdata")
load("output/WD.Rdata")
load("output/WD_canyons.Rdata")
load("output/slr_models.Rdata")

# Find the hive x date instances with a median SLR r2 value
M = ddply(WD_canyons, .(Category), extract_median_fit)
M$Row = as.numeric(rownames(M))
M = M[order(M$N, decreasing=TRUE),]
M

# Find the SLR models by hive and date
slr_models_to_plot = alply(M, 1, function(x) find_slr_model(x$Hive, x$Date))


# Create a list of SLR plots
slr_plots = llply(slr_models_to_plot, plot_segment_model)
G = grid.arrange(grobs=slr_plots, left="Weight (kg)", bottom="Hour")
grid.draw(G)

# Show in TIFF file (to be edited)
tiff("output/fig2_0.tif",1280,800,type="windows")
grid.draw(G)
dev.off()


