responsePlot = function() {
  M = WD_canyons
  M$NightSlope = -M$NightSlope
  alpha = 0.25
  xbreaks12 = c(0, 0.2, 0.3, 0.4, 0.6)
  xbreaks3 = c(-2, -1, 0, 0.6, 1, 2)
  text_size = 3
  grid.arrange(
    ggplot(M, aes(x=CanyonDepth, y=WeightGain)) +
      geom_rect(aes(xmin=0.3, xmax=Inf, ymin=-Inf, ymax=1), fill="grey95", colour=NA) +
      geom_rect(aes(xmin=-Inf, xmax=0.3, ymin=1, ymax=Inf), fill="grey85", colour=NA) +
      geom_point(alpha=alpha, stroke=0) + 
      geom_hline(yintercept=0) + 
      scale_x_continuous(name="Canyon depth (kg)", breaks=xbreaks12, labels=format(xbreaks12, nsmall=1)) +
      scale_y_continuous(name="Weight gain (kg/d)", breaks=-3:2, labels=format(1.0*(-3:2), nsmall=3), limits=c(-2,2.5)) +
      theme_classic() +
      theme(legend.position="none")
    ,
    ggplot(M, aes(x=CanyonDepth, y=NightSlope)) +
      geom_rect(aes(xmin=-Inf, xmax=0.3, ymin=-Inf, ymax=Inf), fill="grey95", colour=NA) +
      geom_rect(aes(xmin=0.3, xmax=Inf, ymin=0, ymax=Inf), fill="grey85", colour=NA) +
      geom_point(alpha=alpha, stroke=0) + 
      geom_hline(yintercept=0) + 
      scale_x_continuous(name="Canyon depth (kg)", breaks=xbreaks12, labels=format(xbreaks12, nsmall=1)) +
      scale_y_continuous(name="Nocturnal loss rate (kg/h)", breaks=seq(-0.1,0.1, 0.025)) +
      theme_classic() +
      theme(legend.position="none")
    ,
    ggplot(M, aes(y=NightSlope, x=WeightGainPrev)) +
      geom_rect(aes(xmin=-1, xmax=0.6, ymin=-Inf, ymax=Inf), fill="grey95", colour=NA) +
      geom_rect(aes(xmin=-Inf, xmax=-1, ymin=0, ymax=Inf), fill="grey85", colour=NA) +
      geom_rect(aes(xmin=0.6, xmax=Inf, ymin=0, ymax=Inf), fill="grey85", colour=NA) +
      geom_point(alpha=alpha, stroke=0) + 
      geom_hline(yintercept=0) + 
      scale_y_continuous(name="Nocturnal loss rate (kg/h)", breaks=seq(-0.1,0.1, 0.025)) +
      scale_x_continuous(name="Weight gain day before (kg/d)", breaks=xbreaks3, labels=format(xbreaks3, nsmall=1), limits=c(-2,2.5)) + 
      theme_classic() +
      theme(legend.position="none")
    ,
    ncol = 1
  )
}

#
# Main
#

load("output/WD_canyons.Rdata")

co = c(
  with(WD_canyons, cor(CanyonDepth, WeightGain, use="complete.obs")),
  with(WD_canyons, cor(CanyonDepth, -NightSlope, use="complete.obs")),
  with(WD_canyons, cor(-NightSlope, WeightGainPrev, use="complete.obs"))
)
co = paste("r =", round(co, 2))
co = str_replace(co, "-", "\u2013") # use proper minus characted

G = responsePlot()

# Show on PDF
pdf("output/fig5.pdf", 5, 8)
grid.draw(G)
dev.off()
