load("output/WD_canyons.Rdata")

my_theme =  
  theme(
    panel.grid.major = element_blank(), 
    panel.grid.minor = element_blank(),
    panel.background = element_blank(), 
    axis.line = element_line(colour = "black"),
    axis.text.y = element_blank(),
    axis.ticks.y = element_blank(),
    strip.text.x = element_text(margin = margin(.1, 0, .1, 0, "cm")),
    legend.key.width  = unit(3, "mm"),
    legend.key.height = unit(3, "mm")
  )

plot_response_densities = function() {
  M = subset(WD_canyons, Period=="After")

  M = M[, c("Treatment","Year","CanyonDepth","WeightGain","NightSlope")]
  M = melt(M, id.vars=c("Treatment","Year"), variable.name="Variable", value.name="Value")
  M = subset(M, !is.na(Value))

  M$Treatment = reorder_levels(M$Treatment, 4:1)
  colours = brewer.pal(7, "Set1")[c(1,4,2,3)]
  alpha=0.45
  grid.arrange(
    ggplot(subset(M, Variable=="CanyonDepth"), aes(x=Value, colour=Treatment, fill=Treatment)) +
      geom_density(alpha=alpha) + 
      labs(title="Breakfast Canyon depth (kg)", x="", y="") +
      scale_colour_manual(values = colours) +
      scale_fill_manual(values = colours) +
      # xlim(CanyonDepthMin, CanyonDepthMax) +
      my_theme +
      facet_wrap(~Year, scales="free_y", ncol=2) 
    ,
    ggplot(subset(M, Variable=="WeightGain"), aes(x=Value, colour=Treatment, fill=Treatment)) +
      geom_density(alpha=alpha) + 
      labs(title="Weight gain (kg/d)", x="", y="") +
      scale_colour_manual(values = colours) +
      scale_fill_manual(values = colours) +
      # xlim(WeightGainMin, WeightGainMax) +
      my_theme +
      facet_wrap(~Year, scales="free_y", ncol=2) 
    ,
    ggplot(subset(M, Variable=="NightSlope"), aes(x=-Value, colour=Treatment, fill=Treatment)) +
      geom_density(alpha=alpha) + 
      labs(title="Nocturnal loss rate (kg/h)", x="", y="") +
      scale_colour_manual(values = colours) +
      scale_fill_manual(values = colours) +
      # xlim(NightSlopeMin, NightSlopeMax) +
      my_theme +
      facet_wrap(~Year, scales="free_y", ncol=2) 
    ,
    ncol=1
  )
}

G = plot_response_densities()
grid.draw(G)

# Surplus legends to be removed by hand
pdf("output/fig6_0.pdf",6,6)
grid.draw(G)
dev.off()

